==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/PRICINGSCHEDULETRADEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PRICINGSCHEDULETRADEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PRICINGSCHEDULETRADEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRICINGSCHEDULEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRADEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OCCUPATIONTYPEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PRICINGSCHEDULETRADEID_Type", propOrder = {
    "pricingscheduleid",
    "tradeid",
    "occupationtypeid",
    "organizationid"
})
public class PRICINGSCHEDULETRADEID_Type {

    @XmlElement(name = "PRICINGSCHEDULEID", required = true)
    protected PRICINGSCHEDULEID_Type pricingscheduleid;
    @XmlElement(name = "TRADEID", required = true)
    protected TRADEID_Type tradeid;
    @XmlElement(name = "OCCUPATIONTYPEID", required = true)
    protected OCCUPATIONTYPEID_Type occupationtypeid;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;

    /**
     * Gets the value of the pricingscheduleid property.
     * 
     * @return
     *     possible object is
     *     {@link PRICINGSCHEDULEID_Type }
     *     
     */
    public PRICINGSCHEDULEID_Type getPRICINGSCHEDULEID() {
        return pricingscheduleid;
    }

    /**
     * Sets the value of the pricingscheduleid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PRICINGSCHEDULEID_Type }
     *     
     */
    public void setPRICINGSCHEDULEID(PRICINGSCHEDULEID_Type value) {
        this.pricingscheduleid = value;
    }

    /**
     * Gets the value of the tradeid property.
     * 
     * @return
     *     possible object is
     *     {@link TRADEID_Type }
     *     
     */
    public TRADEID_Type getTRADEID() {
        return tradeid;
    }

    /**
     * Sets the value of the tradeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TRADEID_Type }
     *     
     */
    public void setTRADEID(TRADEID_Type value) {
        this.tradeid = value;
    }

    /**
     * Gets the value of the occupationtypeid property.
     * 
     * @return
     *     possible object is
     *     {@link OCCUPATIONTYPEID_Type }
     *     
     */
    public OCCUPATIONTYPEID_Type getOCCUPATIONTYPEID() {
        return occupationtypeid;
    }

    /**
     * Sets the value of the occupationtypeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link OCCUPATIONTYPEID_Type }
     *     
     */
    public void setOCCUPATIONTYPEID(OCCUPATIONTYPEID_Type value) {
        this.occupationtypeid = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

}

==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/PRICINGSCHEDULETRADEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour PRICINGSCHEDULETRADEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="PRICINGSCHEDULETRADEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRICINGSCHEDULEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRADEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OCCUPATIONTYPEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PRICINGSCHEDULETRADEID_Type", propOrder = {
    "pricingscheduleid",
    "tradeid",
    "occupationtypeid",
    "organizationid"
})
public class PRICINGSCHEDULETRADEID_Type {

    @XmlElement(name = "PRICINGSCHEDULEID", required = true)
    protected PRICINGSCHEDULEID_Type pricingscheduleid;
    @XmlElement(name = "TRADEID", required = true)
    protected TRADEID_Type tradeid;
    @XmlElement(name = "OCCUPATIONTYPEID", required = true)
    protected OCCUPATIONTYPEID_Type occupationtypeid;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;

    /**
     * Obtient la valeur de la propriété pricingscheduleid.
     * 
     * @return
     *     possible object is
     *     {@link PRICINGSCHEDULEID_Type }
     *     
     */
    public PRICINGSCHEDULEID_Type getPRICINGSCHEDULEID() {
        return pricingscheduleid;
    }

    /**
     * Définit la valeur de la propriété pricingscheduleid.
     * 
     * @param value
     *     allowed object is
     *     {@link PRICINGSCHEDULEID_Type }
     *     
     */
    public void setPRICINGSCHEDULEID(PRICINGSCHEDULEID_Type value) {
        this.pricingscheduleid = value;
    }

    /**
     * Obtient la valeur de la propriété tradeid.
     * 
     * @return
     *     possible object is
     *     {@link TRADEID_Type }
     *     
     */
    public TRADEID_Type getTRADEID() {
        return tradeid;
    }

    /**
     * Définit la valeur de la propriété tradeid.
     * 
     * @param value
     *     allowed object is
     *     {@link TRADEID_Type }
     *     
     */
    public void setTRADEID(TRADEID_Type value) {
        this.tradeid = value;
    }

    /**
     * Obtient la valeur de la propriété occupationtypeid.
     * 
     * @return
     *     possible object is
     *     {@link OCCUPATIONTYPEID_Type }
     *     
     */
    public OCCUPATIONTYPEID_Type getOCCUPATIONTYPEID() {
        return occupationtypeid;
    }

    /**
     * Définit la valeur de la propriété occupationtypeid.
     * 
     * @param value
     *     allowed object is
     *     {@link OCCUPATIONTYPEID_Type }
     *     
     */
    public void setOCCUPATIONTYPEID(OCCUPATIONTYPEID_Type value) {
        this.occupationtypeid = value;
    }

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

}
